@@ -12,15 +12,15 @@
 #include "oxygen.h"
 #include "oxygensettings.h"
 
-#include <KDecoration2/DecoratedClient>
-#include <KDecoration2/Decoration>
-#include <KDecoration2/DecorationSettings>
+#include <KDecoration3/DecoratedWindow>
+#include <KDecoration3/Decoration>
+#include <KDecoration3/DecorationSettings>
 
 #include <QPalette>
 #include <QPropertyAnimation>
 #include <QVariant>
 
-namespace KDecoration2
+namespace KDecoration3
 {
 class DecorationButton;
 class DecorationButtonGroup;
@@ -28,9 +28,8 @@ class DecorationButtonGroup;
 
 namespace Oxygen
 {
-class SizeGrip;
 
-class Decoration : public KDecoration2::Decoration
+class Decoration : public KDecoration3::Decoration
 {
     Q_OBJECT
 
@@ -45,7 +44,7 @@ public:
     ~Decoration() override;
 
     //* paint
-    void paint(QPainter *painter, const QRect &repaintRegion) override;
+    void paint(QPainter *painter, const QRectF &repaintRegion) override;
 
     //* internal settings
     InternalSettingsPtr internalSettings() const
@@ -99,7 +98,6 @@ private Q_SLOTS:
     void updateButtonsGeometryDelayed();
     void updateTitleBar();
     void updateAnimationState();
-    void updateSizeGripVisibility();
     void updateShadow();
 
 private:
@@ -109,16 +107,16 @@ private:
     void createButtons();
 
     //* window background
-    void renderWindowBackground(QPainter *, const QRect &, const QPalette &) const;
+    void renderWindowBackground(QPainter *, const QRectF &, const QPalette &) const;
 
     //* window border
-    void renderWindowBorder(QPainter *, const QRect &, const QPalette &) const;
+    void renderWindowBorder(QPainter *, const QRectF &, const QPalette &) const;
 
     //* title text
     void renderTitleText(QPainter *, const QPalette &) const;
 
     //* corners
-    void renderCorners(QPainter *, const QRect &, const QPalette &) const;
+    void renderCorners(QPainter *, const QRectF &, const QPalette &) const;
 
     //*@name border size
     //@{
@@ -135,24 +133,11 @@ private:
     inline bool hideTitleBar(void) const;
     //@}
 
-    //*@name size grip
-    //@{
-    void createSizeGrip(void);
-    void deleteSizeGrip(void);
-    SizeGrip *sizeGrip(void) const
-    {
-        return m_sizeGrip;
-    }
-    //@}
-
     InternalSettingsPtr m_internalSettings;
 
-    QList<KDecoration2::DecorationButton *> m_buttons;
-    KDecoration2::DecorationButtonGroup *m_leftButtons = nullptr;
-    KDecoration2::DecorationButtonGroup *m_rightButtons = nullptr;
-
-    //* size grip widget
-    SizeGrip *m_sizeGrip = nullptr;
+    QList<KDecoration3::DecorationButton *> m_buttons;
+    KDecoration3::DecorationButtonGroup *m_leftButtons = nullptr;
+    KDecoration3::DecorationButtonGroup *m_rightButtons = nullptr;
 
     //* active state change animation
     QPropertyAnimation *m_animation;
@@ -166,7 +151,7 @@ bool Decoration::hasNoBorders(void) const
     if (m_internalSettings && m_internalSettings->mask() & BorderSize)
         return m_internalSettings->borderSize() == InternalSettings::BorderNone;
     else
-        return settings()->borderSize() == KDecoration2::BorderSize::None;
+        return settings()->borderSize() == KDecoration3::BorderSize::None;
 }
 
 bool Decoration::hasNoSideBorders(void) const
@@ -174,24 +159,24 @@ bool Decoration::hasNoSideBorders(void) const
     if (m_internalSettings && m_internalSettings->mask() & BorderSize)
         return m_internalSettings->borderSize() == InternalSettings::BorderNoSides;
     else
-        return settings()->borderSize() == KDecoration2::BorderSize::NoSides;
+        return settings()->borderSize() == KDecoration3::BorderSize::NoSides;
 }
 
 bool Decoration::isMaximized(void) const
 {
-    return client()->isMaximized() && !m_internalSettings->drawBorderOnMaximizedWindows();
+    return window()->isMaximized() && !m_internalSettings->drawBorderOnMaximizedWindows();
 }
 bool Decoration::isMaximizedHorizontally(void) const
 {
-    return client()->isMaximizedHorizontally() && !m_internalSettings->drawBorderOnMaximizedWindows();
+    return window()->isMaximizedHorizontally() && !m_internalSettings->drawBorderOnMaximizedWindows();
 }
 bool Decoration::isMaximizedVertically(void) const
 {
-    return client()->isMaximizedVertically() && !m_internalSettings->drawBorderOnMaximizedWindows();
+    return window()->isMaximizedVertically() && !m_internalSettings->drawBorderOnMaximizedWindows();
 }
 bool Decoration::hideTitleBar(void) const
 {
-    return m_internalSettings->hideTitleBar() && !client()->isShaded();
+    return m_internalSettings->hideTitleBar() && !window()->isShaded();
 }
 }
 
